@@ -8,10 +8,10 @@
 
 class MariaResult : public DbResult {
 protected:
-  MariaResult(const DbConnectionPtr& pConn, const std::string& sql, bool is_statement);
+  MariaResult(const DbConnectionPtr& pConn, const std::string& sql, bool is_statement, bool immediate);
 
 public:
-  static DbResult* create_and_send_query(const DbConnectionPtr& con, const std::string& sql, bool is_statement);
+  static DbResult* create_and_send_query(const DbConnectionPtr& con, const std::string& sql, bool is_statement, bool immediate);
 
 public:
   void close();
